@@ -32,14 +32,8 @@ clintrials_gov_convert <- function(input, original, output,
   # check against the input schema
   check_in <- xml2::xml_validate(doc, schema_input)
   if( !check_in){ stop("safety data is invalid\n", attr(check_in,"errors"))}
-  
-  # in the testing environment the schema that looks up another schema fails.
-  # issue is raised in github/r-lib/xml2
-  check_in <- ifelse( FALSE,#identical(Sys.getenv("TESTTHAT"), "true"),
-                      TRUE,
-                      xml2::xml_validate(original, schema_output))
+  check_in <- xml2::xml_validate(original, schema_output)
   if( !check_in){ stop("original study file is invalid \n", attr(check_in,"errors"))}
-
   soc <- normalizePath(soc, winslash = "/")
   soc <- gsub("\\s","%20", soc) # As the xslt document() function needs this
   safety <- xslt::xml_xslt(doc, style,params=list(soc_xml_file_path=soc))
@@ -68,9 +62,7 @@ clintrials_gov_convert <- function(input, original, output,
   #check against the output schema
   check_out <- xml2::xml_validate(safety, schema_results)
   if( !check_out){ warning(attr(check_out,"errors"))}
-
-  check_out <- ifelse( identical(Sys.getenv("TESTTHAT"), "true"), TRUE,
-                       xml2::xml_validate(original, schema_output))
+  check_out <- xml2::xml_validate(original, schema_output)
   if( !check_out){ warning(attr(check_out,"errors"))}
 
   message("Please email cuh.cctu@nhs.net to tell us if you have successfully uploaded a study to ClinicalTrials.gov .\nThis is to allow us to measure the impact of this tool.")
